Edit SQL in nano.

```
pip install nanosql
pip install nanosql catsql[mysql]
pip install nanosql catsql[postgres]
```


```
nanosql test.sqlite3
nanosql test.sqlite3 --table users
nanosql postgres[ql]://user:pass@host/db
nanosql test.sqlite3 --table users --grep paul
```
